==> jinrousiki-3.1.0.zip: jinrousiki-3.1.0/include/data/role_sub_data_class.php <==
<?php
//-- 役職データベース (サブ役職) --//
class RoleSubData {
  /* 役職名 (役職通知リストはこの順番で表示される) */
  //サブ役職のリスト (コード名 => 表示名)
  public static $list = array(
    'chicken'			=> '小心者',
    'rabbit'			=> 'ウサギ',
    'perverseness'		=> '天邪鬼',
    'flattery'			=> 'ゴマすり',
    'celibacy'			=> '独身貴族',
    'nervy'			=> '自信家',
    'androphobia'		=> '男性恐怖症',
    'gynophobia'		=> '女性恐怖症',
    'impatience'		=> '短気',
    'febris'			=> '熱病',
    'chill_febris'		=> '悪寒',
    'frostbite'			=> '凍傷',
    'death_warrant'		=> '死の宣告',
    'panelist'			=> '解答者',
    'thorn_cross'		=> '荊十字',
    'infatuated'		=> '惑溺',
    'liar'			=> '狼少年',
    'actor'			=> '役者',
    'passion'			=> '恋色迷彩',
    'rainbow'			=> '虹色迷彩',
    'weekly'			=> '七曜迷彩',
    'grassy'			=> '草原迷彩',
    'invisible'			=> '光学迷彩',
    'side_reverse'		=> '鏡面迷彩',
    'line_reverse'		=> '天地迷彩',
    'gentleman'			=> '紳士',
    'lady'			=> '淑女',
    'cute_camouflage'		=> '魔が言',
    'confession'		=> '告白',
    'decide'			=> '決定者',
    'plague'			=> '疫病神',
    'counter_decide'		=> '燕返し',
    'dropout'			=> '脱落者',
    'good_luck'			=> '幸運',
    'bad_luck'			=> '不運',
    'authority'			=> '権力者',
    'reduce_voter'		=> '無精者',
    'upper_voter'		=> 'わらしべ長者',
    'downer_voter'		=> '没落者',
    'critical_voter'		=> '会心',
    'rebel'			=> '反逆者',
    'random_voter'		=> '気分屋',
    'watcher'			=> '傍観者',
    'day_voter'			=> '一日村長',
    'wirepuller_luck'		=> '入道',
    'upper_luck'		=> '雑草魂',
    'downer_luck'		=> '一発屋',
    'star'			=> '人気者',
    'disfavor'			=> '不人気',
    'critical_luck'		=> '痛恨',
    'random_luck'		=> '波乱万丈',
    'occupied_luck'		=> 'ひんな持ち',
    'strong_voice'		=> '大声',
    'normal_voice'		=> '不器用',
    'weak_voice'		=> '小声',
    'inside_voice'		=> '内弁慶',
    'outside_voice'		=> '外弁慶',
    'upper_voice'		=> 'メガホン',
    'downer_voice'		=> 'マスク',
    'random_voice'		=> '臆病者',
    'tengu_voice'		=> '天狗倒し',
    'no_last_words'		=> '筆不精',
    'blinder'			=> '目隠し',
    'earplug'			=> '耳栓',
    'speaker'			=> 'スピーカー',
    'whisper_ringing'		=> '囁耳鳴',
    'howl_ringing'		=> '吠耳鳴',
    'sweet_ringing'		=> '恋耳鳴',
    'deep_sleep'		=> '爆睡者',
    'silent'			=> '無口',
    'mower'			=> '草刈り',
    'mind_read'			=> 'サトラレ',
    'mind_open'			=> '公開者',
    'mind_receiver'		=> '受信者',
    'mind_friend'		=> '共鳴者',
    'mind_sympathy'		=> '共感者',
    'mind_evoke'		=> '口寄せ',
    'mind_presage'		=> '受託者',
    'mind_lonely'		=> 'はぐれ者',
    'mind_sheep'		=> '羊',
    'wisp'			=> '鬼火',
    'black_wisp'		=> '天火',
    'spell_wisp'		=> '狐火',
    'foughten_wisp'		=> '古戦場火',
    'gold_wisp'			=> '松明丸',
    'tengu_spell_wisp'		=> '天狗火',
    'sheep_wisp'		=> '羊皮',
    'lovers'			=> '恋人',
    'challenge_lovers'		=> '難題',
    'vega_lovers'		=> '織姫',
    'fake_lovers'		=> '愛人',
    'possessed_exchange'	=> '交換憑依',
    'letter_exchange'		=> '交換日記',
    'infected'			=> '感染者',
    'psycho_infected'		=> '洗脳者',
    'joker'			=> 'ジョーカー',
    'rival'			=> '宿敵',
    'enemy'			=> '仇敵',
    'supported'			=> '受援者',
    'bad_status'		=> '悪戯',
    'sweet_status'		=> '悲恋',
    'death_note'		=> 'デスノート',
    'death_selected'		=> 'オシラ遊び',
    'possessed_target'		=> '憑依者',
    'possessed'			=> '憑依',
    'protected'			=> '庇護者',
    'penetration'		=> '護衛貫通',
    'aspirator'			=> '吸毒者',
    'levitation'		=> '空中浮遊',
    'lost_ability'		=> '能力喪失',
    'muster_ability'		=> '能力発現',
    'changed_disguise'		=> '元朔狼',
    'changed_therian'		=> '元獣人',
    'changed_vindictive'	=> '元昼狐',
    'copied'			=> '元神話マニア',
    'copied_trick'		=> '元奇術師',
    'copied_basic'		=> '元求道者',
    'copied_nymph'		=> '元紅天女',
    'copied_soul'		=> '元覚醒者',
    'copied_teller'		=> '元夢語部'
  );
}

==> jinrousiki-4.0.1.zip: jinrousiki-4.0.1/include/data/role_sub_data_class.php <==
<?php
//-- 役職データベース (サブ役職) --//
final class RoleSubData {
  /* 役職名 (役職通知リストはこの順番で表示される) */
  //サブ役職のリスト (コード名 => 表示名)
  public static $list = [
    'chicken'			=> '小心者',
    'rabbit'			=> 'ウサギ',
    'perverseness'		=> '天邪鬼',
    'flattery'			=> 'ゴマすり',
    'celibacy'			=> '独身貴族',
    'nervy'			=> '自信家',
    'androphobia'		=> '男性恐怖症',
    'gynophobia'		=> '女性恐怖症',
    'impatience'		=> '短気',
    'febris'			=> '熱病',
    'chill_febris'		=> '悪寒',
    'frostbite'			=> '凍傷',
    'death_warrant'		=> '死の宣告',
    'panelist'			=> '解答者',
    'thorn_cross'		=> '荊十字',
    'infatuated'		=> '惑溺',
    'liar'			=> '狼少年',
    'actor'			=> '役者',
    'passion'			=> '恋色迷彩',
    'rainbow'			=> '虹色迷彩',
    'weekly'			=> '七曜迷彩',
    'grassy'			=> '草原迷彩',
    'invisible'			=> '光学迷彩',
    'side_reverse'		=> '鏡面迷彩',
    'line_reverse'		=> '天地迷彩',
    'gentleman'			=> '紳士',
    'lady'			=> '淑女',
    'cute_camouflage'		=> '魔が言',
    'confession'		=> '告白',
    'decide'			=> '決定者',
    'plague'			=> '疫病神',
    'counter_decide'		=> '燕返し',
    'dropout'			=> '脱落者',
    'good_luck'			=> '幸運',
    'bad_luck'			=> '不運',
    'authority'			=> '権力者',
    'reduce_voter'		=> '無精者',
    'upper_voter'		=> 'わらしべ長者',
    'downer_voter'		=> '没落者',
    'critical_voter'		=> '会心',
    'rebel'			=> '反逆者',
    'random_voter'		=> '気分屋',
    'watcher'			=> '傍観者',
    'day_voter'			=> '一日村長',
    'wirepuller_luck'		=> '入道',
    'upper_luck'		=> '雑草魂',
    'downer_luck'		=> '一発屋',
    'star'			=> '人気者',
    'disfavor'			=> '不人気',
    'critical_luck'		=> '痛恨',
    'random_luck'		=> '波乱万丈',
    'occupied_luck'		=> 'ひんな持ち',
    'strong_voice'		=> '大声',
    'normal_voice'		=> '不器用',
    'weak_voice'		=> '小声',
    'inside_voice'		=> '内弁慶',
    'outside_voice'		=> '外弁慶',
    'upper_voice'		=> 'メガホン',
    'downer_voice'		=> 'マスク',
    'random_voice'		=> '臆病者',
    'tengu_voice'		=> '天狗倒し',
    'no_last_words'		=> '筆不精',
    'blinder'			=> '目隠し',
    'earplug'			=> '耳栓',
    'speaker'			=> 'スピーカー',
    'whisper_ringing'		=> '囁耳鳴',
    'howl_ringing'		=> '吠耳鳴',
    'sweet_ringing'		=> '恋耳鳴',
    'deep_sleep'		=> '爆睡者',
    'silent'			=> '無口',
    'mower'			=> '草刈り',
    'mind_read'			=> 'サトラレ',
    'mind_open'			=> '公開者',
    'mind_receiver'		=> '受信者',
    'mind_friend'		=> '共鳴者',
    'mind_sympathy'		=> '共感者',
    'mind_evoke'		=> '口寄せ',
    'mind_presage'		=> '受託者',
    'mind_lonely'		=> 'はぐれ者',
    'mind_sheep'		=> '羊',
    'wisp'			=> '鬼火',
    'black_wisp'		=> '天火',
    'spell_wisp'		=> '狐火',
    'foughten_wisp'		=> '古戦場火',
    'gold_wisp'			=> '松明丸',
    'tengu_spell_wisp'		=> '天狗火',
    'sheep_wisp'		=> '羊皮',
    'lovers'			=> '恋人',
    'challenge_lovers'		=> '難題',
    'vega_lovers'		=> '織姫',
    'fake_lovers'		=> '愛人',
    'possessed_exchange'	=> '交換憑依',
    'letter_exchange'		=> '交換日記',
    'infected'			=> '感染者',
    'psycho_infected'		=> '洗脳者',
    'joker'			=> 'ジョーカー',
    'rival'			=> '宿敵',
    'enemy'			=> '仇敵',
    'supported'			=> '受援者',
    'bad_status'		=> '悪戯',
    'sweet_status'		=> '悲恋',
    'death_note'		=> 'デスノート',
    'death_selected'		=> 'オシラ遊び',
    'possessed_target'		=> '憑依者',
    'possessed'			=> '憑依',
    'protected'			=> '庇護者',
    'penetration'		=> '護衛貫通',
    'aspirator'			=> '吸毒者',
    'levitation'		=> '空中浮遊',
    'lost_ability'		=> '能力喪失',
    'muster_ability'		=> '能力発現',
    'changed_disguise'		=> '元朔狼',
    'changed_therian'		=> '元獣人',
    'changed_vindictive'	=> '元昼狐',
    'copied'			=> '元神話マニア',
    'copied_trick'		=> '元奇術師',
    'copied_basic'		=> '元求道者',
    'copied_nymph'		=> '元紅天女',
    'copied_soul'		=> '元覚醒者',
    'copied_teller'		=> '元夢語部'
  ];
}
